﻿motdstripper = LibStub("AceAddon-3.0"):NewAddon("MOTDstripper")

function options()
	local options = {
	    name = "MOTDstripper",
	    handler = motdstripper,
	    type = "group",
	    args = {
	        header = {
	            order = 1,
	            type = "description",
	            name = "  " .. L["Notes"],
	            image = "Interface\\Icons\\Spell_Holy_Stoicism",
	            imageWidth = 32,
	            imageHeight = 32,
	        },
	        extralinebreak = {
	            order = 2,
	            type = "description",
	            name = "\n",
	        },
	        whattostrip = {
	        	order = 3,
	        	type = "group",
	        	name = L["MsgsToStrip"],
	        	inline = true,
	        	args = {
			        stripgmotd = {
			        	order = 1,
			        	type = "toggle",
			        	width = "full",
			        	name = L["StripG"],
			        	desc = L["StripGDesc"],
			        	get = function() return motdstripperpc.stripgmotd end,
			        	set = function() motdstripperpc.stripgmotd = not motdstripperpc.stripgmotd end,
			        },
			        stripsmotd = {
			        	order = 2,
			        	type = "toggle",
			        	width = "full",
			        	name = L["StripS"],
			        	desc = L["StripSDesc"],
			        	get = function() return motdstripperpc.stripsmotd end,
			        	set = function() motdstripperpc.stripsmotd = not motdstripperpc.stripsmotd end,
			        },
	        	},
	        },
	    },
	}
	LibStub("AceConfig-3.0"):RegisterOptionsTable("MOTDstripper", options, nil)
	LibStub("AceConfigDialog-3.0"):AddToBlizOptions("MOTDstripper")
end

function motdstripper:OnInitialize()
  -- Code that you want to run when the addon is first loaded goes here.
end

function motdstripper:OnEnable()
    -- Called when the addon is enabled
end

function motdstripper:OnDisable()
    -- Called when the addon is disabled
end

local arg = nil
local okaytoshow = nil
local t = nil
local elapsed = 0
local update_interval = 1
local filters = nil
local gmotd_now = nil
local gmotd_last_loaded = nil
local smotd_now = nil
local smotd_last_loaded = nil
local ERR_DUNGEON_DIFFICULTY_CHANGED_S = string.gsub(ERR_DUNGEON_DIFFICULTY_CHANGED_S, "%%s.*", "")

function motdstripper_onload()
	this:RegisterEvent("ADDON_LOADED")
	this:RegisterEvent("GUILD_MOTD")
	this:RegisterEvent("CHAT_MSG_SYSTEM")
end

local function msg(msg)
	DEFAULT_CHAT_FRAME:AddMessage(msg)
end

local function chatfilter()
	if elapsed <= update_interval then
		return true
	end
end

function motdstripper_onevent(self, event, ...)
	if event == "ADDON_LOADED" and ... == "MOTDstripper" then
		options()
		if motdstripperpc ~= nil then
			if motdstripperpc.gmotd_last_saved ~= nil then
				gmotd_last_loaded = motdstripperpc.gmotd_last_saved
			end
			if motdstripperpc.smotd_last_saved ~= nil then
				smotd_last_loaded = motdstripperpc.smotd_last_saved
			end
			if motdstripperpc.stripgmotd == nil then
				motdstripperpc.stripgmotd = true
			end
			if motdstripperpc.stripsmotd == nil then
				motdstripperpc.stripsmotd = true
			end
		else
			motdstripperpc = {}
		end
		this:UnregisterEvent("ADDON_LOADED")
	end
	if event == "GUILD_MOTD" and motdstripperpc.stripgmotd then
		gmotd_now = ...
		motdstripperpc.gmotd_last_saved = gmotd_now
		if gmotd_last_loaded == gmotd_now then
			GUILD_MOTD_TEMPLATE = string.gsub(GUILD_MOTD_TEMPLATE, ".*", "")
		end
		this:UnregisterEvent("GUILD_MOTD")
	end
	if event == "CHAT_MSG_SYSTEM" and motdstripperpc.stripsmotd then
		if t then
			elapsed = time() - t
		end
		if elapsed <= update_interval then
			arg = ...
			if string.find(arg, ERR_DUNGEON_DIFFICULTY_CHANGED_S) then
				okaytoshow = arg
				arg = ""
			end
			if smotd_now then
				smotd_now = smotd_now .. " " .. arg
			else
				smotd_now = arg
			end
			motdstripperpc.smotd_last_saved = smotd_now
			if not okaytoshow and smotd_last_loaded and string.match(smotd_last_loaded, smotd_now) then
				ChatFrame_AddMessageEventFilter("CHAT_MSG_SYSTEM", chatfilter)
			end
			okaytoshow = nil
		else
			this:UnregisterEvent("CHAT_MSG_SYSTEM")
			filters = ChatFrame_GetMessageEventFilters("CHAT_MSG_SYSTEM")
			if filters then
				for i=1, #filters do
					ChatFrame_RemoveMessageEventFilter("CHAT_MSG_SYSTEM", chatfilter)
				end
			end
		end
		t = time()
	end
end